import React from 'react';
import ReactDOM from 'react-dom';
import { arc } from 'd3';

const width = 960;
const height = 500;
const hairH = 100;
const centerX = width / 2;
const centerY = (height + hairH) / 2;
const radiusY = (height - hairH) / 2;
const strokeWidth = 13;
const eyeOffsetX = 125;
const eyeOffsetY = 50;
const eyebrowYOffset = -70;
const eyeRadius = 35;
const mouthWidth = 10;
const mouthRadius = 45;

// Creation of mouth arc
const mouthArc = arc()
  .innerRadius(-mouthRadius)
  .outerRadius(mouthRadius + mouthWidth)
  .startAngle(Math.PI / 2)
  .endAngle((Math.PI * 3) / 2);

// Creation of eye arc
const eyeArc = arc()
  .innerRadius(26)
  .outerRadius(40)
  .startAngle(-Math.PI / 3)
  .endAngle(Math.PI / 3);

// Creation of ear arc
const earArc = arc()
  .innerRadius(0)
  .outerRadius(80)
  .startAngle(-Math.PI / 2)
  .endAngle(Math.PI / 2);

const App = () => {
  const mouthProps = {
    d: mouthArc(),
    transform: 'translate(-6,60)',
    fill: 'red',
  };

  const earProps = {
    d: earArc(),
    fill: 'black',
    transform: 'rotate(70) translate(10,-195)',
  };

  return (
    <svg width={width} height={height}>
      <g transform={`translate(${centerX},${centerY})`}>
        <circle
          r={radiusY - strokeWidth / 3}
          fill="yellow"
          stroke="black"
          strokeWidth={strokeWidth}
        />
        <circle
          cx={-eyeOffsetX}
          cy={-eyeOffsetY}
          r={eyeRadius}
          fill="white"
          stroke="black"
          strokeWidth="8"
        />
        <circle
          cx={eyeOffsetX}
          cy={-eyeOffsetY}
          r={eyeRadius}
          fill="white"
          stroke="black"
          strokeWidth="8"
        />
        <circle
          cx={eyeOffsetX}
          cy={-eyeOffsetY}
          r={eyeRadius / 3}
          fill="black"
          stroke="white"
        />
        <circle
          cx={-eyeOffsetX}
          cy={-eyeOffsetY}
          r={eyeRadius / 3}
          fill="black"
          stroke="white"
        />
        <ellipse
          rx={eyeRadius}
          ry={eyeRadius / 2}
          fill="orange"
          stroke="black"
          transform="rotate(-90)"
        />
        <line
          x1={100}
          y1={33}
          x2={30}
          y2={10}
          stroke="red"
          strokeWidth="2"
        />
        <line
          x1={-100}
          y1={33}
          x2={-30}
          y2={10}
          stroke="red"
          strokeWidth="2"
        />
        <line
          x1={-100}
          y1={20}
          x2={-30}
          y2={10}
          stroke="green"
          strokeWidth="2"
        />
        <line
          x1={100}
          y1={20}
          x2={30}
          y2={10}
          stroke="green"
          strokeWidth="2"
        />
        <line
          x1={100}
          y1={10}
          x2={30}
          y2={10}
          stroke="red"
          strokeWidth="2"
        />
        <line
          x1={-100}
          y1={10}
          x2={-30}
          y2={10}
          stroke="red"
          strokeWidth="2"
        />
        <path
          d={eyeArc()}
          transform="rotate(5) translate(-132,-68)"
          fill="black"
        />
        <path
          d={eyeArc()}
          transform="rotate(-5) translate(132,-68)"
          fill="black"
        />
        <path {...earProps} />
        <path {...mouthProps} />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
